Summary:        Framework for managing passwords and other secrets
Name:           mate-keyring
Version:        1.5.0
Release:        2%{?dist}
License:        GPLv2+ and LGPLv2+
Group:          System Environment/Libraries
URL:            http://mate-desktop.org
Source0:        http://pub.mate-desktop.org/releases/1.5/%{name}-%{version}.tar.xz
# upstream commits
# https://github.com/mate-desktop/mate-keyring/commit/0269af132af17ecea87f869cda26100cd9b724a8
# https://github.com/mate-desktop/mate-keyring/commit/de7a2884feb7acd6abcd7f0bcb7eac963c787f4f
Patch0:         upstream_commits.patch


BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(mate-keyring-1)
BuildRequires:  pkgconfig(libtasn1)
BuildRequires:  libtasn1-tools
BuildRequires:  libgcrypt-devel
BuildRequires:  pam-devel
BuildRequires:  mate-common
BuildRequires:  libcap-devel

Requires: libmatekeyring

%description
The mate-keyring session daemon manages passwords and other types of
secrets for the user, storing them encrypted with a main password.
Applications can use the mate-keyring library to integrate with the keyring.

%package devel
Summary: Development files for mate-keyring
License: LGPLv2+
Group: Development/Libraries
Requires: %{name}%{?_isa} = %{version}-%{release}
Requires: libmatekeyring-devel

%description devel
The mate-keyring-devel package contains the libraries and
header files needed to develop applications that use mate-keyring.

%package pam
Summary: MATE Desktop pam module for unlocking keyrings
License: LGPLv2+
Requires: %{name}%{?_isa} = %{version}-%{release}

%description pam
Shared library for MATE Desktop pam auth


%prep
%setup -q -n mate-keyring-%{version}
%patch0 -p1
NOCONFIGURE=1 ./autogen.sh

%build
%configure --disable-static \
           --with-gtk=2.0 \
           --enable-pam \
           --with-pam-dir=/%{_lib}/security \
           --with-root-certs=%{_sysconfdir}/pki/tls/certs

# avoid unneeded direct dependencies
sed -i -e 's! -shared ! -Wl,--as-needed\0!g' libtool

make %{?_smp_mflags} V=1

%install
make DESTDIR=%{buildroot} install
find %{buildroot} -name '*.la' -exec rm -rf {} ';'
find %{buildroot} -name '*.a' -exec rm -rf {} ';'

# Fix permissions on mate-keyring-daemon
chmod 0755 %{buildroot}%{_bindir}/mate-keyring-daemon

%find_lang %{name}


%post -p /sbin/ldconfig

%postun
/sbin/ldconfig
if [ $1 -eq 0 ]; then
  /usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &>/dev/null || :
fi

%posttrans
/usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &>/dev/null || :


%files -f %{name}.lang
%doc AUTHORS NEWS README COPYING COPYING.LIB
%{_bindir}/mate-keyring
%{_bindir}/mate-keyring-daemon
%{_sysconfdir}/xdg/autostart/mate-keyring-pkcs11.desktop
%{_sysconfdir}/xdg/autostart/mate-keyring-secrets.desktop
%{_sysconfdir}/xdg/autostart/mate-keyring-ssh.desktop
%{_sysconfdir}/xdg/autostart/mate-keyring-gpg.desktop
%{_libexecdir}/mate-keyring-prompt
%{_libdir}/lib*.so.*
%{_libdir}/mate-keyring/
%{_libdir}/pkcs11/mate-keyring-pkcs11.so
%{_datadir}/dbus-1/services/*.service
%{_datadir}/mategcr/
%{_datadir}/mate-keyring/
%{_datadir}/MateConf/gsettings/*.convert
%{_datadir}/glib-2.0/schemas/*.gschema.xml

%files pam
/%{_lib}/security/pam_mate_keyring.so

%files devel
%doc %{_datadir}/gtk-doc/html/mate-gck/
%doc %{_datadir}/gtk-doc/html/mate-gcr-0/
%{_includedir}/mategcr/
%{_includedir}/mate-gck/
%{_includedir}/gck/
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*

%changelog
* Thu Nov 08 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.5.0-2
- patch with latest upstream fixes

* Mon Oct 29 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.5.0-1
- update to 1.5.0 release
- drop upstream patch

* Tue Oct 23 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.4.0-14
- Tell configure where the certs are.
- Tell configure where pam security is.

* Tue Oct 23 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.4.0-13
- Drop requires pam and glib2-devel
- Drop build requires mateconf-devel, mate-doc-utils, mate-desktop and libselinux-devel
- Swap build requires dbus-glib-develfor dbus-devel

* Tue Oct 23 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.4.0-12
- Fix directory ownership
- Remove desktop-file-utils build requires and validation on xdg files
- Remove surplus configure options
- Drop un-needed build requires
- Add requires pam to pam sub-package
- Re-add sed command to avoid unneeded direct dependencies
- Fix permissions on mate-keyring-daemon

* Mon Oct 22 2012 Dan Mashal <dan.mashal@fedoraproject.org> - 1.4.0-11
- Update BR

* Mon Oct 22 2012 Dan Mashal <dan.mashal@fedoraproject.org> - 1.4.0-10
- Update configure flags, add desktop file install section for desktop files, add requires

* Mon Oct 22 2012 Dan Mashal <dan.mashal@fedoraproject.org> - 1.4.0-9
- Clean up specfile

* Sun Aug 05 2012 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.4.0-8
- fix rpmlint error unused-direct-shlib-dependency

* Sun Aug 05 2012 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.4.0-7
- fix mixed use of $RPM_BUILD_ROOT & %%{buildroot}
- rename patch to mate
- fix requires in -devel
- fix scriplet sections

* Sat Aug 04 2012 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.4.0-6
- initial build for fedora
- edit start-gnome-keyring-in-mate sources

* Sun Dec 25 2011 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.1.0-1
- mate-file-manager.spec based on gnome-keyring-2.32.0-1.fc14 spec
